@@ -52,26 +52,22 @@ double  *pA,
 pG = new(nothrow) int [(1+int(mtype==1 || mtype==3))*nind*nloci];
 if(pG==NULL)
 {
-Rprintf("NO MEMORY for G\n");
-exit(1);
+ error("NO MEMORY for G\n");
 }
 G = new(nothrow) int* [nind];
 if(G==NULL)
 {
-Rprintf("NO MEMORY for G\n");
-exit(1);
+ error("NO MEMORY for G\n");
 }
 pA = new(nothrow) double [nloci*maxall];
 if(pA==NULL)
 {
-Rprintf("NO MEMORY for A\n");
-exit(1);
+ error("NO MEMORY for A\n");
 }
 A = new(nothrow) double* [nloci];
 if(A==NULL)
 {
-Rprintf("NO MEMORY for A\n");
-exit(1);
+ error("NO MEMORY for A\n");
 }
 
 for (i=0; i<nind; ++i){
